<?php

namespace Drupal\Tests\menu_firstchild\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests the menu_firstchild_form_menu_link_content_form_alter function.
 *
 * @group menu_firstchild
 */
class MenuFirstchildFormAlterTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['menu_firstchild', 'menu_link_content'];

  /**
   * Default theme.
   *
   * @var string
   */
  protected $defaultTheme = 'claro';

  /**
   * Tests the form alteration.
   */
  public function testFormAlter() {
    // Create a menu link content entity.
    $menu_link = $this->createMenuLinkContent();

    // Use the 'entity.form_builder' service to build the form.
    $form_builder = \Drupal::service('entity.form_builder');
    $form = $form_builder->getForm($menu_link);

    // Assert that the form contains the altered elements.
    $this->assertArrayHasKey('menu_firstchild_enabled', $form);
    $this->assertEquals(FALSE, $form['menu_firstchild_enabled']['#default_value']);
    $this->assertEquals('<div id="menu-firstchild-link-wrapper">', $form['link']['#prefix']);
  }

  /**
   * Creates a menu link content entity for testing.
   *
   * @return \Drupal\menu_link_content\Entity\MenuLinkContent
   *   The menu link content entity.
   */
  protected function createMenuLinkContent() {
    return $this->container->get('entity_type.manager')
      ->getStorage('menu_link_content')
      ->create([
        'title' => 'Test Menu Link',
        'menu_name' => 'main',
        'link' => ['uri' => 'internal:/test'],
      ]);
  }

}
